import { EventResolvable } from '../util/Types';
import GuildBlock from './blocks/GuildBlock';
import UserBlock from './blocks/UserBlock';
import ClientUser from './ClientUser';
import Intents from './Intents';
import Websocket from './websocket/Websocket';
export default class Client {
    private valid;
    private devtools;
    token: string;
    ws: Websocket;
    me: ClientUser | null;
    shard: any;
    options: {
        intents: Intents;
        debug: boolean;
    };
    guilds: GuildBlock;
    users: UserBlock;
    private events;
    constructor(options: {
        intents: Intents;
        debug?: boolean;
    });
    /**
     * Add an event listener.
     *
     * @param {EventResolvable | string} event The event name.
     * @param {Function} listener The function to call when the event is emitted.
     * @returns {void}
     */
    listen(event: EventResolvable | string, callback: Function): void;
    /**
     * Undind an event listener.
     *
     * @param {EventResolvable | string} event The event name to unbind.
     * @returns {void}
     */
    unbind(event: EventResolvable | string): void;
    /**
     * Emit an event.
     *
     * @param {EventResolvable | string} event The event name.
     * @param {any} data The event data to pass to the listener.
     * @returns {void}
     */
    emit(event: EventResolvable | string, ...args: any[]): any;
    /**
     * Initilize a new addon to the client.
     *
     * @param {Function} fn The addon's main function.
     * @returns {any} The updated client.
     */
    add(fn: Function): Client;
    /**
     * Connect to the Discord gateway.
     *
     * ⚠️ **DON'T SHARE YOUR GOD DAMN TOKEN!** There is no
     * reason anyone should need it, with the exception of
     * your development team. ANYONE with your token can
     * gain FULL and UNRESTRICTED ACCESS to the entirety of
     * your bot, INCLUDING ANY PERMISSIONS IT HAS BEEN
     * GRANTED. Bot takeovers have happened far too often
     * in the past: don't let your bot join the list.
     *
     * @param {string} token Your bot's token.
     * @returns {void}
     */
    connect(token: string): void;
    /**
     * Emit a log in debug mode.
     *
     * @param {any} message The log message.
     * @returns {void}
     */
    debug(...message: any[]): void;
    /**
     * Emit a warning in debug mode.
     *
     * @param {any} message The warning message.
     * @returns {void}
     */
    warn(...message: any[]): void;
    /**
     * Log a packet received from the gateway.
     *
     * @param {any} message The packet data.
     * @returns {void}
     */
    private logReceive;
    /**
     * Log a packet sent to the gateway.
     *
     * @param {any} message The packet data.
     * @returns {void}
     */
    private logSend;
    /**
     * Log a HTTP event.
     *
     * @param {any} message The event data.
     * @returns {void}
     */
    private logHttp;
    /**
     * Only registers the provided event if it isn't
     * already registered.
     */
    private listenIfNotRegistered;
    /**
     * Invalidate the client, forcing the user to restart
     * the process to use it. Once called, this cannot be
     * undone (mostly because it would defeat the entire
     * purpose of this function).
     */
    private invalidate;
}
