import Client from '../Client';
import Role from '../Role';
import PermissionsBlock from './PermissionsBlock';
export default class RolePermissionsBlock extends PermissionsBlock {
    role: Role;
    constructor(client: Client, role: Role, ...flags: number[]);
    /**
     * Grant the role the specified permissions.
     *
     * @param {Permissions.FLAGS | number[] | number} permissions The permissions to grant.
     * @param {Object} options The options for the action.
     * @param {string} [options.reason] The reason for the action.
     * @returns {Promise<Role>} A Promise that resolves to the modified Role.
     */
    grant(permissions: number[] | number, options?: {
        reason?: string;
    }): Promise<Role>;
    /**
     * Revoke the specified permissions from the Role.
     *
     * @param {Permissions.FLAGS | number[] | number} permissions The permissions to revoke.
     * @param {Object} options The options for the action.
     * @param {string} [options.reason] The reason for the action.
     * @returns {Promise<Role>} A Promise that resolves to the modified Role.
     */
    revoke(permissions: number[] | number, options?: {
        reason?: string;
    }): Promise<Role>;
    /**
     * Set the permissions for the Role.
     *
     * @param {Permissions.FLAGS | number[] | number} permissions The permissions to set.
     * @param {Object} options The options for the action.
     * @param {string} [options.reason] The reason for the action.
     * @returns {Promise<Role>} A Promise that resolves to the modified Role.
     */
    set(permissions: number[] | number, options?: {
        reason?: string;
    }): Promise<Role>;
}
